pub struct FocusEventRecord {
pub set_focus: bool,
}Expand description
Represents a FOCUS_EVENT_RECORD which Describes a focus event in a console INPUT_RECORD structure.
These events are used internally and should be ignored.
link: https://docs.microsoft.com/en-us/windows/console/focus-event-record-str
Fields
set_focus: boolReserved.